@@ -1,7 +1,7 @@
 package Pod::From::Acme::CPANModules;
 
-our $DATE = '2019-01-11'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2020-04-30'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -57,8 +57,6 @@ sub gen_pod_from_acme_cpanmodules {
 
         {
             my $pod = '';
-            $pod .= "$list->{summary}".($list->{summary} =~ /\.$/ ? "" : ".")."\n\n"
-                if $list->{summary};
             $pod .= _markdown_to_pod($list->{description})."\n\n"
                 if $list->{description} && $list->{description} =~ /\S/;
             $res->{pod}{DESCRIPTION} = $pod if $pod;
@@ -109,7 +107,7 @@ Pod::From::Acme::CPANModules - Create "INCLUDED MODULES" POD sections from $LIST
 
 =head1 VERSION
 
-This document describes version 0.002 of Pod::From::Acme::CPANModules (from Perl distribution Pod-From-Acme-CPANModules), released on 2019-01-11.
+This document describes version 0.003 of Pod::From::Acme::CPANModules (from Perl distribution Pod-From-Acme-CPANModules), released on 2020-04-30.
 
 =head1 SYNOPSIS
 
@@ -140,6 +138,7 @@ As an alternative to `module`, you can directly supply $LIST here.
 
 =item * B<module> => I<str>
 
+
 =back
 
 Return value:  (any)
@@ -166,7 +165,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
